==> jc-1.4.0.tar.gz: polyglot/util/AllowBreak.h <==
// class polyglot.util.AllowBreak

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class bc2875222b1ccf02 polyglot_util_AllowBreak
// @dep_class 77b6315f0d7667d7 polyglot_util_Item

// header file dependencies
// @dep_header polyglot_util_Item

#include "polyglot/util/Item.h"

#ifndef _JC_polyglot_util_AllowBreak_H_
#define _JC_polyglot_util_AllowBreak_H_

// Forward structure declarations
struct _jc_java_io_Writer$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_polyglot_util_AllowBreak$sub_refs	_jc_polyglot_util_AllowBreak$sub_refs;
typedef struct _jc_polyglot_util_AllowBreak$sub_nonrefs	_jc_polyglot_util_AllowBreak$sub_nonrefs;
typedef struct _jc_polyglot_util_AllowBreak$refs	_jc_polyglot_util_AllowBreak$refs;
typedef struct _jc_polyglot_util_AllowBreak$nonrefs	_jc_polyglot_util_AllowBreak$nonrefs;
typedef struct _jc_polyglot_util_AllowBreak$object	_jc_polyglot_util_AllowBreak$object;

typedef const struct _jc_polyglot_util_AllowBreak$vmethods	_jc_polyglot_util_AllowBreak$vmethods;
typedef const struct _jc_polyglot_util_AllowBreak$vtable	_jc_polyglot_util_AllowBreak$vtable;
typedef const struct _jc_polyglot_util_AllowBreak$vtype	_jc_polyglot_util_AllowBreak$vtype;

// Constructors
extern void _jc_polyglot_util_AllowBreak$method$_init$206934d97c5ba451(_jc_env *, struct _jc_polyglot_util_AllowBreak$object *, jint, struct _jc_java_lang_String$object *);

// Virtual methods
extern jint _jc_polyglot_util_AllowBreak$method$formatN$d2e3422217490f28(_jc_env *, struct _jc_polyglot_util_AllowBreak$object *, jint, jint, jint, jint, jboolean, jboolean);
extern jboolean _jc_polyglot_util_AllowBreak$method$selfContainsBreaks$eee83a7eb63480c0(_jc_env *, struct _jc_polyglot_util_AllowBreak$object *);
extern jint _jc_polyglot_util_AllowBreak$method$selfMinIndent$1bd739bebfa9e596(_jc_env *, struct _jc_polyglot_util_AllowBreak$object *);
extern jint _jc_polyglot_util_AllowBreak$method$selfMinPosWidth$0744953d4c491ab4(_jc_env *, struct _jc_polyglot_util_AllowBreak$object *);
extern jint _jc_polyglot_util_AllowBreak$method$selfMinWidth$865467bfe90a636b(_jc_env *, struct _jc_polyglot_util_AllowBreak$object *);
extern struct _jc_java_lang_String$object *_jc_polyglot_util_AllowBreak$method$selfToString$1fede6a6d66caf4a(_jc_env *, struct _jc_polyglot_util_AllowBreak$object *);
extern jint _jc_polyglot_util_AllowBreak$method$sendOutput$7012ec94d3c70bcd(_jc_env *, struct _jc_polyglot_util_AllowBreak$object *, struct _jc_java_io_Writer$object *, jint, jint);

// Virtual method descriptors
extern _jc_method _jc_polyglot_util_AllowBreak$method_info$formatN$d2e3422217490f28;
extern _jc_method _jc_polyglot_util_AllowBreak$method_info$selfContainsBreaks$eee83a7eb63480c0;
extern _jc_method _jc_polyglot_util_AllowBreak$method_info$selfMinIndent$1bd739bebfa9e596;
extern _jc_method _jc_polyglot_util_AllowBreak$method_info$selfMinPosWidth$0744953d4c491ab4;
extern _jc_method _jc_polyglot_util_AllowBreak$method_info$selfMinWidth$865467bfe90a636b;
extern _jc_method _jc_polyglot_util_AllowBreak$method_info$selfToString$1fede6a6d66caf4a;
extern _jc_method _jc_polyglot_util_AllowBreak$method_info$sendOutput$7012ec94d3c70bcd;

// Virtual methods structure
struct _jc_polyglot_util_AllowBreak$vmethods {
	jint	(*formatN$d2e3422217490f28)(_jc_env *, struct _jc_polyglot_util_AllowBreak$object *, jint, jint, jint, jint, jboolean, jboolean);
	jboolean	(*selfContainsBreaks$eee83a7eb63480c0)(_jc_env *, struct _jc_polyglot_util_AllowBreak$object *);
	jint	(*selfMinIndent$1bd739bebfa9e596)(_jc_env *, struct _jc_polyglot_util_AllowBreak$object *);
	jint	(*selfMinPosWidth$0744953d4c491ab4)(_jc_env *, struct _jc_polyglot_util_AllowBreak$object *);
	jint	(*selfMinWidth$865467bfe90a636b)(_jc_env *, struct _jc_polyglot_util_AllowBreak$object *);
	struct _jc_java_lang_String$object	*(*selfToString$1fede6a6d66caf4a)(_jc_env *, struct _jc_polyglot_util_AllowBreak$object *);
	jint	(*sendOutput$7012ec94d3c70bcd)(_jc_env *, struct _jc_polyglot_util_AllowBreak$object *, struct _jc_java_io_Writer$object *, jint, jint);
};

// Vtable
struct _jc_polyglot_util_AllowBreak$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_util_Item$vmethods	polyglot_util_Item;
	_jc_polyglot_util_AllowBreak$vmethods	polyglot_util_AllowBreak;
};

// Vtype
struct _jc_polyglot_util_AllowBreak$vtype {
	_jc_type			type;
	_jc_polyglot_util_AllowBreak$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_util_AllowBreak$sub_refs {
	struct _jc_java_lang_String$object	*alt;
};

// Reference instance fields (object)
struct _jc_polyglot_util_AllowBreak$refs {
    _jc_polyglot_util_AllowBreak$sub_refs	polyglot_util_AllowBreak;
    _jc_polyglot_util_Item$sub_refs	polyglot_util_Item;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_util_AllowBreak$sub_nonrefs {
	jint	indent;
	jboolean	broken;
};

// Non-reference instance fields (object)
struct _jc_polyglot_util_AllowBreak$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_util_Item$sub_nonrefs	polyglot_util_Item;
    _jc_polyglot_util_AllowBreak$sub_nonrefs	polyglot_util_AllowBreak;
};

// Object instance structure
struct _jc_polyglot_util_AllowBreak$object {
	_jc_polyglot_util_AllowBreak$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_util_AllowBreak$vtype	*vtype;
	_jc_polyglot_util_AllowBreak$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_util_AllowBreak$vtype _jc_polyglot_util_AllowBreak$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_util_AllowBreak, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_util_AllowBreak$class_object;

#endif	/* _JC_polyglot_util_AllowBreak_H_ */

==> jc-1.4.6.tar.gz: polyglot/util/AllowBreak.h <==
// class polyglot.util.AllowBreak

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class bc2875222b1ccf02 polyglot_util_AllowBreak
// @dep_class 77b6315f0d7667d7 polyglot_util_Item

// header file dependencies
// @dep_header polyglot_util_Item

#include "polyglot/util/Item.h"

#ifndef _JC_polyglot_util_AllowBreak_H_
#define _JC_polyglot_util_AllowBreak_H_

// Forward structure declarations
struct _jc_java_io_Writer$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_polyglot_util_AllowBreak$sub_refs	_jc_polyglot_util_AllowBreak$sub_refs;
typedef struct _jc_polyglot_util_AllowBreak$sub_nonrefs	_jc_polyglot_util_AllowBreak$sub_nonrefs;
typedef struct _jc_polyglot_util_AllowBreak$refs	_jc_polyglot_util_AllowBreak$refs;
typedef struct _jc_polyglot_util_AllowBreak$nonrefs	_jc_polyglot_util_AllowBreak$nonrefs;
typedef struct _jc_polyglot_util_AllowBreak$object	_jc_polyglot_util_AllowBreak$object;

typedef const struct _jc_polyglot_util_AllowBreak$vmethods	_jc_polyglot_util_AllowBreak$vmethods;
typedef const struct _jc_polyglot_util_AllowBreak$vtable	_jc_polyglot_util_AllowBreak$vtable;
typedef const struct _jc_polyglot_util_AllowBreak$vtype	_jc_polyglot_util_AllowBreak$vtype;

// Constructors
extern void _jc_polyglot_util_AllowBreak$method$_init$206934d97c5ba451(_jc_env *, struct _jc_polyglot_util_AllowBreak$object *, jint, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_polyglot_util_AllowBreak$method$formatN$d2e3422217490f28(_jc_env *, struct _jc_polyglot_util_AllowBreak$object *, jint, jint, jint, jint, jboolean, jboolean) _JC_JCNI_ATTR;
extern jboolean _jc_polyglot_util_AllowBreak$method$selfContainsBreaks$eee83a7eb63480c0(_jc_env *, struct _jc_polyglot_util_AllowBreak$object *) _JC_JCNI_ATTR;
extern jint _jc_polyglot_util_AllowBreak$method$selfMinIndent$1bd739bebfa9e596(_jc_env *, struct _jc_polyglot_util_AllowBreak$object *) _JC_JCNI_ATTR;
extern jint _jc_polyglot_util_AllowBreak$method$selfMinPosWidth$0744953d4c491ab4(_jc_env *, struct _jc_polyglot_util_AllowBreak$object *) _JC_JCNI_ATTR;
extern jint _jc_polyglot_util_AllowBreak$method$selfMinWidth$865467bfe90a636b(_jc_env *, struct _jc_polyglot_util_AllowBreak$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_polyglot_util_AllowBreak$method$selfToString$1fede6a6d66caf4a(_jc_env *, struct _jc_polyglot_util_AllowBreak$object *) _JC_JCNI_ATTR;
extern jint _jc_polyglot_util_AllowBreak$method$sendOutput$7012ec94d3c70bcd(_jc_env *, struct _jc_polyglot_util_AllowBreak$object *, struct _jc_java_io_Writer$object *, jint, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_util_AllowBreak$method_info$formatN$d2e3422217490f28;
extern _jc_method _jc_polyglot_util_AllowBreak$method_info$selfContainsBreaks$eee83a7eb63480c0;
extern _jc_method _jc_polyglot_util_AllowBreak$method_info$selfMinIndent$1bd739bebfa9e596;
extern _jc_method _jc_polyglot_util_AllowBreak$method_info$selfMinPosWidth$0744953d4c491ab4;
extern _jc_method _jc_polyglot_util_AllowBreak$method_info$selfMinWidth$865467bfe90a636b;
extern _jc_method _jc_polyglot_util_AllowBreak$method_info$selfToString$1fede6a6d66caf4a;
extern _jc_method _jc_polyglot_util_AllowBreak$method_info$sendOutput$7012ec94d3c70bcd;

// Virtual methods structure
struct _jc_polyglot_util_AllowBreak$vmethods {
	jint	(*formatN$d2e3422217490f28)(_jc_env *, struct _jc_polyglot_util_AllowBreak$object *, jint, jint, jint, jint, jboolean, jboolean) _JC_JCNI_ATTR;
	jboolean	(*selfContainsBreaks$eee83a7eb63480c0)(_jc_env *, struct _jc_polyglot_util_AllowBreak$object *) _JC_JCNI_ATTR;
	jint	(*selfMinIndent$1bd739bebfa9e596)(_jc_env *, struct _jc_polyglot_util_AllowBreak$object *) _JC_JCNI_ATTR;
	jint	(*selfMinPosWidth$0744953d4c491ab4)(_jc_env *, struct _jc_polyglot_util_AllowBreak$object *) _JC_JCNI_ATTR;
	jint	(*selfMinWidth$865467bfe90a636b)(_jc_env *, struct _jc_polyglot_util_AllowBreak$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*selfToString$1fede6a6d66caf4a)(_jc_env *, struct _jc_polyglot_util_AllowBreak$object *) _JC_JCNI_ATTR;
	jint	(*sendOutput$7012ec94d3c70bcd)(_jc_env *, struct _jc_polyglot_util_AllowBreak$object *, struct _jc_java_io_Writer$object *, jint, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_util_AllowBreak$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_util_Item$vmethods	polyglot_util_Item;
	_jc_polyglot_util_AllowBreak$vmethods	polyglot_util_AllowBreak;
};

// Vtype
struct _jc_polyglot_util_AllowBreak$vtype {
	_jc_type			type;
	_jc_polyglot_util_AllowBreak$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_util_AllowBreak$sub_refs {
	struct _jc_java_lang_String$object	*alt;
};

// Reference instance fields (object)
struct _jc_polyglot_util_AllowBreak$refs {
    _jc_polyglot_util_AllowBreak$sub_refs	polyglot_util_AllowBreak;
    _jc_polyglot_util_Item$sub_refs	polyglot_util_Item;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_util_AllowBreak$sub_nonrefs {
	jint	indent;
	jboolean	broken;
};

// Non-reference instance fields (object)
struct _jc_polyglot_util_AllowBreak$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_util_Item$sub_nonrefs	polyglot_util_Item;
    _jc_polyglot_util_AllowBreak$sub_nonrefs	polyglot_util_AllowBreak;
};

// Object instance structure
struct _jc_polyglot_util_AllowBreak$object {
	_jc_polyglot_util_AllowBreak$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_util_AllowBreak$vtype	*vtype;
	_jc_polyglot_util_AllowBreak$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_util_AllowBreak$vtype _jc_polyglot_util_AllowBreak$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_util_AllowBreak, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_util_AllowBreak$class_object;

#endif	/* _JC_polyglot_util_AllowBreak_H_ */
